@@ -2,7 +2,7 @@
 //! `Fibroblast` from some serialized data (e.g. a directory with the necessary manifest
 //! and files)
 
-use super::decoding_error::ClgnDecodingResult;
+use super::decoding_error::{ClgnDecodingError, ClgnDecodingResult};
 use crate::fibroblast::{data_types::DecodingContext, tags::RootTag, Fibroblast};
 use serde_json;
 use std::path::Path;
@@ -21,8 +21,10 @@ impl<'a> Fibroblast<'a> {
 		let path = path.as_ref();
 
 		let manifest_path = path.join("collagen.json");
-		let reader = std::fs::File::open(&manifest_path)?;
-		let root = serde_json::from_reader::<_, RootTag>(reader)?;
+		let reader = std::fs::File::open(&manifest_path)
+			.map_err(|e| ClgnDecodingError::Io(e, manifest_path.clone()))?;
+		let root = serde_json::from_reader::<_, RootTag>(reader)
+			.map_err(|e| ClgnDecodingError::JsonDecode(e, manifest_path))?;
 
 		Ok(Fibroblast { root, context })
 	}
